@@ -5,7 +5,7 @@ Copyright (C) 2022 Humankind Investments
 
 import pandas as pd
 import numpy as np
-from db_utils import database_connect
+from .db_utils import database_connect
 
 
 # CLEANING DUPLICATE AND SPLIT VISITS +++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -451,4 +451,4 @@ def drop_dev(df, db_dict):
     dev= pd.read_sql(query, conn)
     conn.close()
     df= df.loc[~df['visitor_id'].isin(dev['visitor_id'])]
-    return df
\ No newline at end of file
+    return df
